*********
Nengo GUI
*********

Nengo GUI is an HTML5 interactive visualizer for
`Nengo <https://github.com/nengo/nengo>`_.
It lets you see the structure of a Nengo model, plot spiking activity and
decoded representations among other visualizations, and adjust the inputs while
the model is running.

.. toctree::
   :maxdepth: 2

   getting_started
   examples
   user_guide
   dev_guide

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`